@@ -166,11 +166,7 @@ class Circle(ScreenProgram):
         # Thus, import it here instead of at the top of the file
         import pi3d
         from pi3d.util.OffScreenTexture import OffScreenTexture
-        from pi3d.constants import (
-            opengles,
-            GL_CLAMP_TO_EDGE,
-            GL_ALWAYS,
-        )
+        from pi3d.constants import opengles, GL_CLAMP_TO_EDGE, GL_ALWAYS
 
         # used for reimplementing the draw call with instancing
         from pi3d.constants import (
@@ -285,7 +281,7 @@ class Circle(ScreenProgram):
         self.logo.positionZ(0)
 
         logo_image = Image.open(
-            os.path.join(settings.STATIC_ROOT, "graphics/raveberry_square.png")
+            os.path.join(settings.STATIC_FILES, "graphics/raveberry_square.png")
         )
         self.logo_array = np.frombuffer(logo_image.tobytes(), dtype=np.uint8)
         self.logo_array = self.logo_array.reshape(
