@@ -2,13 +2,16 @@
 
 from __future__ import annotations
 
+from typing import Optional, List, TYPE_CHECKING
+
 import requests
 import soundcloud
 from bs4 import BeautifulSoup
-
-from core.musiq.music_provider import SongProvider, PlaylistProvider
 from django.http.response import HttpResponse
-from typing import Optional, List, Tuple, TYPE_CHECKING
+
+from core.musiq import song_utils
+from core.musiq.song_provider import SongProvider
+from core.musiq.playlist_provider import PlaylistProvider
 
 if TYPE_CHECKING:
     from core.musiq.musiq import Musiq
@@ -34,7 +37,7 @@ class Soundcloud:
         If not, it is created using the client-id from mopidy-soundcloud."""
         return Soundcloud._get_web_client()
 
-    def get_search_suggestions(self, query: str) -> List[Tuple[str, str]]:
+    def get_search_suggestions(self, query: str) -> List[str]:
         """Returns a list of suggested items for the given query."""
 
         response = self.web_client.get(
@@ -55,6 +58,7 @@ class SoundcloudSongProvider(SongProvider, Soundcloud):
 
     @staticmethod
     def get_id_from_internal_url(url: str) -> str:
+        """Returns the internal id based on the given url."""
         return url.split(".")[-1]
 
     def __init__(
@@ -77,10 +81,17 @@ class SoundcloudSongProvider(SongProvider, Soundcloud):
     def gather_metadata(self) -> bool:
         """Fetches metadata for this song's uri from Soundcloud."""
         if not self.id:
-            results = self.web_client.get("/tracks", q=self.query, limit=1)
-            try:
-                result = results[0]
-            except IndexError:
+            results = self.web_client.get("/tracks", q=self.query, limit=20)
+
+            # apply the filterlist from the settings
+            for item in results:
+                if not song_utils.contains_keywords(
+                    item.title, self.musiq.base.settings.basic.forbidden_keywords
+                ):
+                    result = item
+                    break
+            else:
+                # all tracks got filtered
                 return False
             self.id = result.id
         else:
