@@ -6,19 +6,17 @@ from __future__ import annotations
 import random
 from typing import TYPE_CHECKING, Dict, Union, List
 
-from django.db.models import Q
-from django.http import HttpResponseBadRequest, JsonResponse
+from django.core.handlers.wsgi import WSGIRequest
+from django.http import HttpResponseBadRequest
+from django.http.response import JsonResponse, HttpResponse
+from watson import search as watson
 
 import core.musiq.song_utils as song_utils
 from core.models import ArchivedPlaylist, ArchivedSong
-from core.musiq.music_provider import SongProvider
+from core.musiq.song_provider import SongProvider
 from core.musiq.soundcloud import Soundcloud
 from core.musiq.spotify import Spotify
 from core.musiq.youtube import Youtube
-from django.core.handlers.wsgi import WSGIRequest
-from django.http.response import JsonResponse, HttpResponse
-
-from watson import search as watson
 
 if TYPE_CHECKING:
     from core.musiq.musiq import Musiq
@@ -55,34 +53,26 @@ class Suggestions:
         playlist = remaining_playlists.all()[index]
         return JsonResponse({"suggestion": playlist.title, "key": playlist.id})
 
-    def get_suggestions(self, request: WSGIRequest) -> JsonResponse:
-        """Returns suggestions for a given query.
-        Combines online and offline suggestions."""
-        query = request.GET["term"]
-        suggest_playlist = request.GET["playlist"] == "true"
-
+    def _online_suggestions(
+        self, query, suggest_playlist
+    ) -> List[Dict[str, Union[str, int]]]:
         results: List[Dict[str, Union[str, int]]] = []
-
         if (
-            self.musiq.base.settings.online_suggestions
-            and self.musiq.base.settings.has_internet
+            self.musiq.base.settings.basic.online_suggestions
+            and self.musiq.base.settings.basic.has_internet
         ):
+            platform_settings = self.musiq.base.settings.platforms
 
-            number_of_suggestions = 2
-            if [
-                self.musiq.base.settings.spotify_enabled,
-                self.musiq.base.settings.soundcloud_enabled,
-                self.musiq.base.settings.youtube_enabled,
-            ].count(True) > 1:
-                # If there is more than one active service,
-                # only offer one online suggestion per service
-                number_of_suggestions = 1
-
-            if self.musiq.base.settings.spotify_enabled:
+            if (
+                platform_settings.spotify_enabled
+                and platform_settings.spotify_suggestions > 0
+            ):
                 spotify_suggestions = Spotify().get_search_suggestions(
                     query, suggest_playlist
                 )
-                spotify_suggestions = spotify_suggestions[:number_of_suggestions]
+                spotify_suggestions = spotify_suggestions[
+                    : platform_settings.spotify_suggestions
+                ]
                 for suggestion, external_url in spotify_suggestions:
                     results.append(
                         {
@@ -92,25 +82,49 @@ class Suggestions:
                         }
                     )
 
-            if self.musiq.base.settings.soundcloud_enabled:
+            if (
+                platform_settings.soundcloud_enabled
+                and platform_settings.soundcloud_suggestions > 0
+            ):
                 soundcloud_suggestions = Soundcloud().get_search_suggestions(query)
-                soundcloud_suggestions = soundcloud_suggestions[:number_of_suggestions]
+                soundcloud_suggestions = soundcloud_suggestions[
+                    : platform_settings.soundcloud_suggestions
+                ]
                 for suggestion in soundcloud_suggestions:
                     results.append(
                         {"key": -1, "value": suggestion, "type": "soundcloud-online"}
                     )
 
-            if self.musiq.base.settings.youtube_enabled:
+            if (
+                platform_settings.youtube_enabled
+                and platform_settings.youtube_suggestions > 0
+            ):
                 youtube_suggestions = Youtube().get_search_suggestions(query)
-                # limit to the first three online suggestions
-                youtube_suggestions = youtube_suggestions[:number_of_suggestions]
+                youtube_suggestions = youtube_suggestions[
+                    : platform_settings.youtube_suggestions
+                ]
                 for suggestion in youtube_suggestions:
                     results.append(
                         {"key": -1, "value": suggestion, "type": "youtube-online"}
                     )
+        return results
+
+    def get_suggestions(self, request: WSGIRequest) -> JsonResponse:
+        """Returns suggestions for a given query.
+        Combines online and offline suggestions."""
+        query = request.GET["term"]
+        suggest_playlist = request.GET["playlist"] == "true"
+
+        if self.musiq.base.settings.basic.new_music_only and not suggest_playlist:
+            return JsonResponse([], safe=False)
+
+        results = self._online_suggestions(query, suggest_playlist)
+        basic_settings = self.musiq.base.settings.basic
 
         if suggest_playlist:
-            search_results = watson.search(query, models=(ArchivedPlaylist,))[:20]
+            search_results = watson.search(query, models=(ArchivedPlaylist,))[
+                : basic_settings.number_of_suggestions
+            ]
 
             for playlist in search_results:
                 playlist_info = playlist.meta
@@ -118,12 +132,14 @@ class Suggestions:
                 result_dict: Dict[str, Union[str, int]] = {
                     "key": playlist_info["id"],
                     "value": playlist_info["title"],
-                    "counter": playlist_info["counter"],
+                    "counter": playlist.object.counter,
                     "type": song_utils.determine_playlist_type(archived_playlist),
                 }
                 results.append(result_dict)
         else:
-            search_results = watson.search(query, models=(ArchivedSong,))[:20]
+            search_results = watson.search(query, models=(ArchivedSong,))[
+                : basic_settings.number_of_suggestions
+            ]
 
             for search_result in search_results:
                 song_info = search_result.meta
@@ -135,23 +151,23 @@ class Suggestions:
                 if not cached and provider.type == "local":
                     continue
                 # don't suggest online songs when we don't have internet
-                if not self.musiq.base.settings.has_internet and not cached:
+                if not self.musiq.base.settings.basic.has_internet and not cached:
                     continue
                 # don't suggest youtube songs if it was disabled
                 if (
-                    not self.musiq.base.settings.youtube_enabled
+                    not self.musiq.base.settings.platforms.youtube_enabled
                     and provider.type == "youtube"
                 ):
                     continue
                 # don't suggest spotify songs if we are not logged in
                 if (
-                    not self.musiq.base.settings.spotify_enabled
+                    not self.musiq.base.settings.platforms.spotify_enabled
                     and provider.type == "spotify"
                 ):
                     continue
                 # don't suggest soundcloud songs if we are not logged in
                 if (
-                    not self.musiq.base.settings.soundcloud_enabled
+                    not self.musiq.base.settings.platforms.soundcloud_enabled
                     and provider.type == "soundcloud"
                 ):
                     continue
@@ -160,7 +176,7 @@ class Suggestions:
                     "value": song_utils.displayname(
                         song_info["artist"], song_info["title"]
                     ),
-                    "counter": song_info["counter"],
+                    "counter": search_result.object.counter,
                     "type": provider.type,
                 }
                 results.append(result_dict)
