@@ -9,15 +9,7 @@ import os
 import pickle
 import subprocess
 from contextlib import contextmanager
-from typing import (
-    Any,
-    Dict,
-    List,
-    Optional,
-    TYPE_CHECKING,
-    Iterator,
-    cast,
-)
+from typing import Any, Dict, List, Optional, TYPE_CHECKING, Iterator, cast
 from urllib.parse import parse_qs
 from urllib.parse import urlparse
 
@@ -49,9 +41,7 @@ def youtube_session() -> Iterator[requests.Session]:
     except FileNotFoundError:
         pass
 
-    headers = {
-        "User-Agent": youtube_dl.utils.random_user_agent(),
-    }
+    headers = {"User-Agent": youtube_dl.utils.random_user_agent()}
     session.headers.update(headers)
     yield session
 
@@ -113,10 +103,13 @@ class Youtube:
     def _get_initial_data(html: str) -> Dict[str, Any]:
         for line in html.split("\n"):
             line = line.strip()
-            prefix = 'window["ytInitialData"] = '
-            if line.startswith(prefix):
-                # strip assignment and semicolon
-                initial_data = line[len(prefix) : -1]
+            before = "var ytInitialData = "
+            after = ";</script>"
+            if before in line:
+                # extract json
+                initial_data = line[
+                    line.index(before) + len(before) : line.index(after)
+                ]
                 return json.loads(initial_data)
         raise ValueError("Could not parse initial data from html")
 
