@@ -52,8 +52,6 @@ INSTALLED_APPS = [
     "django.contrib.messages",
     "django.contrib.staticfiles",
     "watson",
-    "compressor",
-    "sass_processor",
     "channels",
 ]
 
@@ -82,9 +80,9 @@ TEMPLATES = [
                 "django.template.context_processors.request",
                 "django.contrib.auth.context_processors.auth",
                 "django.contrib.messages.context_processors.messages",
-            ],
+            ]
         },
-    },
+    }
 ]
 
 CSRF_FAILURE_VIEW = "core.util.csrf_failure"
@@ -132,7 +130,7 @@ else:
 # Password validation
 AUTH_PASSWORD_VALIDATORS = [
     {
-        "NAME": "django.contrib.auth.password_validation.UserAttributeSimilarityValidator",
+        "NAME": "django.contrib.auth.password_validation.UserAttributeSimilarityValidator"
     },
     {"NAME": "django.contrib.auth.password_validation.MinimumLengthValidator"},
     {"NAME": "django.contrib.auth.password_validation.CommonPasswordValidator"},
@@ -158,10 +156,8 @@ LOGOUT_REDIRECT_URL = "/"
 # SESSION_COOKIE_AGE = 3600
 
 # Static files (CSS, JavaScript, Images)
-STATIC_ROOT = os.path.join(BASE_DIR, "static")
-STATICFILES_DIRS: List[str] = [
-    # os.path.join(BASE_DIR, "staticfiles/"),
-]
+STATIC_FILES = os.path.join(BASE_DIR, "static")
+STATICFILES_DIRS: List[str] = [STATIC_FILES]
 STATIC_URL = "/static/"
 
 if not os.path.exists(os.path.join(BASE_DIR, "static/admin")) and not MOCK:
@@ -171,9 +167,7 @@ if not os.path.exists(os.path.join(BASE_DIR, "static/admin")) and not MOCK:
     STATIC_ADMIN = os.path.join(DJANGO_PATH, "contrib/admin/static/admin")
     if DOCKER:
         # copy the files since nginx runs in another container
-        shutil.copytree(
-            STATIC_ADMIN, os.path.join(BASE_DIR, "static/admin"),
-        )
+        shutil.copytree(STATIC_ADMIN, os.path.join(BASE_DIR, "static/admin"))
         print("copied static admin files")
     else:
         # create symlink to admin static files if not present
@@ -184,27 +178,13 @@ if not os.path.exists(os.path.join(BASE_DIR, "static/admin")) and not MOCK:
         )
         print("linked static admin files")
 
-
-# adapted for django-compressor and sass-processor
-SASS_PROCESSOR_ROOT = STATIC_ROOT
-# Change this to True if you are changing scss files.
-SASS_PROCESSOR_ENABLED = False
-
-STATICFILES_FINDERS = (
-    "django.contrib.staticfiles.finders.FileSystemFinder",
-    "django.contrib.staticfiles.finders.AppDirectoriesFinder",
-    # other finders..
-    "compressor.finders.CompressorFinder",
-    "sass_processor.finders.CssFinder",
-)
-
 # channels
 ASGI_APPLICATION = "main.routing.APPLICATION"
 CHANNEL_LAYERS = {
     "default": {
         "BACKEND": "channels_redis.core.RedisChannelLayer",
         "CONFIG": {"hosts": [(REDIS_HOST, 6379)], "capacity": 1500, "expiry": 10},
-    },
+    }
 }
 
 # Logging
@@ -221,7 +201,7 @@ LOGGING = {
             "datefmt": "%Y-%m-%d %H:%M:%S",
         },
         "brief": {
-            "format": "%(module)s.%(funcName)s:%(lineno)s %(levelname)s  %(message)s",
+            "format": "%(module)s.%(funcName)s:%(lineno)s %(levelname)s  %(message)s"
         },
     },
     "handlers": {
