@@ -15,18 +15,17 @@ fi
 if [[ -z "$DB_BACKUP" ]]; then
 	if [[ ! $db_exists = true ]]; then
 		echo "Performing migrations"
-		sudo -Hu www-data DJANGO_MOCK=1 python3 manage.py migrate
+		sudo -Hu www-data DJANGO_MOCK=1 DJANGO_POSTGRES=1 python3 manage.py migrate
 		echo "Creating Users"
 		if [[ "$ADMIN_PASSWORD" == "admin" ]]; then
 			echo "!!! Warning! Using default admin password 'admin' !!!"
 			echo "!!!     change this later in the webinterface     !!!"
 			echo "!!!           at http://raveberry/admin           !!!"
 		fi
-		sudo -Hu www-data DJANGO_MOCK=1 python3 manage.py shell <<-EOF
+		sudo -Hu www-data DJANGO_MOCK=1 DJANGO_POSTGRES=1 python3 manage.py shell <<-EOF
 			from django.contrib.auth.models import User
 			User.objects.create_superuser('admin', email='', password='$ADMIN_PASSWORD')
 			User.objects.create_user('mod', password='mod')
-			User.objects.create_user('pad', password='pad')
 		EOF
 	fi
 else
@@ -38,25 +37,24 @@ else
 	sudo -u postgres psql raveberry < $DB_BACKUP
 fi
 echo "Initializing search engine"
-sudo -Hu www-data DJANGO_MOCK=1 python3 manage.py migrate
-sudo -Hu www-data DJANGO_MOCK=1 python3 manage.py installwatson
-sudo -Hu www-data DJANGO_MOCK=1 python3 manage.py buildwatson
+sudo -Hu www-data DJANGO_MOCK=1 DJANGO_POSTGRES=1 python3 manage.py migrate
+sudo -Hu www-data DJANGO_MOCK=1 DJANGO_POSTGRES=1 python3 manage.py installwatson
+sudo -Hu www-data DJANGO_MOCK=1 DJANGO_POSTGRES=1 python3 manage.py buildwatson
 
 if [ ! -z "$DEV_USER" ] && [ ! -f db.sqlite3 ]; then
 	echo "*** Creating Debug Database ***"
 	echo "Performing Migrations"
-	sudo -Hu www-data DJANGO_DEBUG=1 DJANGO_MOCK=1 python3 manage.py migrate
+	sudo -Hu www-data DJANGO_MOCK=1 python3 manage.py migrate
 	echo "Creating Users"
 	if [[ "$ADMIN_PASSWORD" == "admin" ]]; then
 		echo "!!! Warning! Using default admin password 'admin' !!!"
 		echo "!!!     change this later in the webinterface     !!!"
 		echo "!!!        at http://raveberry:8000/admin         !!!"
 	fi
-	sudo -Hu www-data DJANGO_DEBUG=1 DJANGO_MOCK=1 python3 manage.py shell <<-EOF
+	sudo -Hu www-data DJANGO_MOCK=1 python3 manage.py shell <<-EOF
 		from django.contrib.auth.models import User
 		User.objects.create_superuser('admin', email='', password='$ADMIN_PASSWORD')
 		User.objects.create_user('mod', password='mod')
-		User.objects.create_user('pad', password='pad')
 	EOF
 else
 	echo "Debug database already exists, no migration needed"
