@@ -8,13 +8,9 @@ DJANGO_MOCK=1 python3 manage.py shell <<-EOF
 	User.objects.create_superuser('admin', email='', password='$ADMIN_PASSWORD')
 	User.objects.create_user('mod', password='mod')
 EOF
-if [[ ! -d static/libs ]]; then
-	echo "Installing frontend libraries"
-	HOME= yarn install
-fi
-if [[ ! -f static/scss/dark.css ]]; then
-	echo "Compiling SCSS Files"
-	DJANGO_MOCK=1 python3 manage.py compilescss
+if [[ ! -d static/bundle.js ]]; then
+	echo "building frontend"
+	cd frontend && yarn build && cd ..
 fi
 
 if [ "$ADMIN_PASSWORD" == "admin" ]; then
